shouldShowButtons property
bool
get
shouldShowButtons
Should the buttons be visible in the current build mode
Implementation
bool get shouldShowButtons => !_showButtonsInDebugOnly || kDebugMode;
Should the buttons be visible in the current build mode
bool get shouldShowButtons => !_showButtonsInDebugOnly || kDebugMode;